@@ -29,9 +29,6 @@ generate the SVG for the entire map.
 
 This class is derived from L<Game::TextMapper::Mapper>.
 
-It uses L<Game::TextMapper::Point::Square> to represent points (regions) and
-L<Game::TextMapper::Line::Square> to represent lines.
-
 L<Game::TextMapper::Mapper::Hex> is a similar class for hex maps.
 
 =cut
@@ -39,7 +36,7 @@ L<Game::TextMapper::Mapper::Hex> is a similar class for hex maps.
 package Game::TextMapper::Mapper::Square;
 
 use Game::TextMapper::Constants qw($dy);
-use Game::TextMapper::Point::Square;
+use Game::TextMapper::Square;
 use Game::TextMapper::Line::Square;
 
 use Modern::Perl '2018';
@@ -47,7 +44,7 @@ use Mojo::Base 'Game::TextMapper::Mapper';
 
 sub make_region {
   my $self = shift;
-  return Game::TextMapper::Point::Square->new(@_);
+  return Game::TextMapper::Square->new(@_);
 }
 
 sub make_line {
@@ -58,8 +55,8 @@ sub make_line {
 sub shape {
   my $self = shift;
   my $attributes = shift;
-  return sprintf('<rect %s x="%.1f" y="%.1f" width="%.1f" height="%.1f" />',
-		 $attributes, -$dy/2, -$dy/2, $dy, $dy);
+  my $half = $dy / 2;
+  return qq{<rect $attributes x="-$half" y="-$half" width="$dy" height="$dy" />};
 }
 
 sub viewbox {
