@@ -19,19 +19,6 @@
 
 Game::TextMapper::Schroeder::Hex - a role for hex map generators
 
-=head1 SYNOPSIS
-
-    # create a map
-    package World;
-    use Modern::Perl;
-    use Mojo::Base -base;
-    use Role::Tiny::With;
-    with 'Game::TextMapper::Schroeder::Base';
-    with 'Game::TextMapper::Schroeder::Hex';
-    # use it
-    package main;
-    my $map = World->new(height => 10, width => 10);
-
 =head1 DESCRIPTION
 
 This role provides basic functionality for map generation with hex maps: the
@@ -39,60 +26,25 @@ number of neighbours within one or two regions distance, how to pick a random
 neighbour direction, how to compute the coordinates of these neighbours, how to
 draw arrows towards these neighbours.
 
-This inherits attributes and methods from L<Game::TextMapper::Schroeder::Base>,
-such as C<width> and C<height>.
+This class is different from L<Game::TextMapper::Hex>!
+
+=head1 SEE ALSO
+
+L<Game::TextMapper::Schroeder::Base>
+L<Game::TextMapper::Schroeder::Square>
 
 =cut
 
 package Game::TextMapper::Schroeder::Hex;
 use Modern::Perl '2018';
 use Mojo::Base -role;
-use POSIX qw(ceil);
-
-=head1 METHODS
-
-=head2 reverse
-
-Reverses a direction.
-
-=cut
-
-sub reverse {
-  my ($self, $i) = @_;
-  return ($i + 3) % 6;
-}
-
-=head2 neighbors
-
-The list of directions for neighbours one step away (0 to 5).
-
-=cut
 
 sub neighbors { 0 .. 5 }
 
-=head2 neighbors2
-
-The list of directions for neighbours two steps away (0 to 11).
-
-=cut
-
 sub neighbors2 { 0 .. 11 }
 
-=head2 random_neighbor
-
-A random direction for a neighbour one step away (a random integer from 0 to 5).
-
-=cut
-
 sub random_neighbor { int(rand(6)) }
 
-=head2 random_neighbor2
-
-A random direction for a neighbour two steps away (a random integer from 0 to
-11).
-
-=cut
-
 sub random_neighbor2 { int(rand(12)) }
 
 my $delta_hex = [
@@ -101,21 +53,6 @@ my $delta_hex = [
   # x is odd
   [[-1, -1], [ 0, -1], [+1, -1], [+1,  0], [ 0, +1], [-1,  0]]];
 
-=head2 neighbor($hex, $i)
-
-    say join(",", $map->neighbor("0203", 1));
-    # 2,2
-
-Returns the coordinates of a neighbor in a particular direction (0 to 5), one
-step away.
-
-C<$hex> is an array reference of coordinates or a string that can be turned into
-one using the C<xy> method from L<Game::TextMapper::Schroeder::Base>.
-
-C<$i> is a direction (0 to 5).
-
-=cut
-
 sub neighbor {
   my $self = shift;
   # $hex is [x,y] or "0x0y" and $i is a number 0 .. 5
@@ -134,21 +71,6 @@ my $delta_hex2 = [
   [[-2, +1], [-2,  0], [-2, -1], [-1, -2], [ 0, -2], [+1, -2],
    [+2, -1], [+2,  0], [+2, +1], [+1, +1], [ 0, +2], [-1, +1]]];
 
-=head2 neighbor2($hex, $i)
-
-    say join(",", $map->neighbor2("0203", 1));
-    # 0, 3
-
-Returns the coordinates of a neighbor in a particular direction (0 to 11), two
-steps away.
-
-C<$hex> is an array reference of coordinates or a string that can be turned into
-one using the C<xy> method from L<Game::TextMapper::Schroeder::Base>.
-
-C<$i> is a direction (0 to 5).
-
-=cut
-
 sub neighbor2 {
   my $self = shift;
   # $hex is [x,y] or "0x0y" and $i is a number 0 .. 11
@@ -159,15 +81,6 @@ sub neighbor2 {
 	  $hex->[1] + $delta_hex2->[$hex->[0] % 2]->[$i]->[1]);
 }
 
-=head2 distance($x1, $y1, $x2, $y2) or distance($coords1, $coords2)
-
-    say $map->distance("0203", "0003");
-    # 2
-
-Returns the distance between two coordinates.
-
-=cut
-
 sub distance {
   my $self = shift;
   my ($x1, $y1, $x2, $y2) = @_;
@@ -194,30 +107,14 @@ sub distance {
   }
 }
 
-=head2 arrows
-
-A helper that returns the SVG fragments for arrows in six directions, to be used
-in a C<defs> element.
-
-=cut
-
 sub arrows {
   my $self = shift;
   return
       qq{<marker id="arrow" markerWidth="6" markerHeight="6" refX="6" refY="3" orient="auto"><path d="M6,0 V6 L0,3 Z" style="fill: black;" /></marker>},
-      qq{<marker id="wind" markerWidth="6" markerHeight="6" refX="6" refY="3" orient="auto"><path d="M6,0 V6 L0,3 Z" style="fill: purple;" /></marker>},
       map {
 	my $angle = 60 * $_;
 	qq{<path id="arrow$_" transform="rotate($angle)" d="M-11.5,-5.8 L11.5,5.8" style="stroke: black; stroke-width: 3px; fill: none; marker-start: url(#arrow);"/>},
-	qq{<path id="wind$_" transform="translate(40,40) rotate($angle)" d="M-11.5,-5.8 L11.5,5.8" style="stroke: purple; stroke-width: 3px; fill: none; marker-start: url(#wind);"/>},
   } ($self->neighbors());
 }
 
-=head1 SEE ALSO
-
-L<Game::TextMapper::Schroeder::Base>
-L<Game::TextMapper::Schroeder::Square>
-
-=cut
-
 1;
